<?php
/**
 * Vidéo
 * @license GNU General Public License, version 3
 * @link https://deltacms.fr/
 * @Lionel Croquefer 2024
 */
class video extends common {
	public static $actions = [
		'index' => self::GROUP_VISITOR,
		'config' => self::GROUP_MODERATOR
	];
	public static $listDirs = [];
	public static $videos = [];

	const VERSION ='1.4';
	const REALNAME = 'Vidéo';
	const DELETE = true;
	const UPDATE = '0.0';
	const DATADIRECTORY = '';

	// Mise à jour de la version du module
	private function update() {
		if (null === $this->getData(['module', $this->getUrl(0), 'config', 'versionData']) ) {
				$this->init();
			}
		else {
			if (version_compare($this->getData(['module', $this->getUrl(0), 'config', 'versionData']), self::VERSION, '<')) {
				$this->setData(['module', $this->getUrl(0), 'config', 'versionData', self::VERSION]);
			}
		}
	}

	// Initialisation
	private function init() {
		$this->setData(['module', $this->getUrl(0), 'config', 'versionData', self::VERSION]);
	}

	// Paramétrage du module,
	public function config() {
		// Autorisation
		$group = $this->getUser('group');
		if ($group === false ) $group = 0;
		if ($group < video::$actions['config']) {
			// Valeurs en sortie
			$this->addOutput(['access' => false]);
		} else {
		// Lexique
		include('./module/video/lang/'. $this->getData(['config', 'i18n', 'langAdmin']) . '/lex_video.php');

		// liste les dossiers contenant des vidéos
		$filter = ['mp4','m4v','webm'];
			self::$listDirs = helper::scanDir(self::FILE_DIR.'source', $filter);
			sort(self::$listDirs);

		// formulaire posté
		if($this->isPost()) {
			$legends = [];
			foreach((array) $this->getInput('legend', null) as $file => $legend) {
				$file = str_replace('.','-',$file);
				$legends[$file] = helper::filter($legend, helper::FILTER_STRING_SHORT);
			}
			// Enregistrement dans module.json
			$this->setData(['module', $this->getUrl(0), [
				'config' => [
				'directory' => self::$listDirs[$this->getInput('videoConfigDirectory')],
				'versionData' => self::VERSION
				],
				'legend' => $legends
				]]);

			// Message et redirection après enregistrement de la configuration
			$this->addOutput([
				'redirect' => helper::baseUrl() . $this->getUrl(0),
				'notification' => $text['video']['config'][0],
				'state' => true
				]);
			}

			// Préparation du tableau d'édition des légendes
			$directory = $this->getData(['module', $this->getUrl(0), 'config', 'directory']);
			if (is_dir($directory)) {
			$resultats = videoHelper::recherche($directory);
			foreach ($resultats as $fileFound) {
					if (videoHelper::autorise($fileFound)) {
						self::$videos[basename($fileFound)] = [
							basename($fileFound),
							template::text('legend[' . basename($fileFound) . ']', [
								'value' => $this->getData(['module', $this->getUrl(0), 'legend', str_replace('.','-',basename($fileFound))])
							])
						];
					}
				}
			}

			// ALLER à la configuration du module
			$this->addOutput([
				'title' => $text['video']['config'][1],
				'view' => 'config'
			]);
		}
	}

	public function index() {
		if( null === $this->getData(['module', $this->getUrl(0), 'config', 'versionData']) ||  version_compare($this->getData(['module', $this->getUrl(0), 'config', 'versionData']), self::VERSION, '<') ) $this->update();
		// Lexique
		include('./module/video/lang/'. $this->getData(['config', 'i18n', 'langAdmin']) . '/lex_video.php');

		// Module non configuré ?
		if (null === $this->getData(['module', $this->getUrl(0), 'config', 'directory' ])) {
			// ALLER à la configuration du module
			$this->addOutput([
				'redirect' => helper::baseUrl() . $this->getUrl(0).'/config',
				'notification' => $text['video']['index'][0],
				'state' => true
			]);
		}

		// Valeurs en sortie
		$this->addOutput([
			'showBarEditButton' => true,
			'showPageContent' => true,
			'view' => 'index'
		]);
	}
}
class videoHelper extends helper {
// réécriture des noms
public static function separe($nom) {
	$separateurs = ['-','_','.'];
    return str_replace($separateurs, ' ', $nom);
}
// limite de caractères
public static function smaller($nomcourt) {
$len = 30;
if (strlen($nomcourt) >= $len) {$nomcourt = substr($nomcourt,0,$len) . '...' ;}
   return $nomcourt;
   }
// recherche de vidéos
public static function recherche($dossier) {
	$recherche = glob($dossier.'/*.{mp4,m4v,webm,MP4,M4V,WEBM}', GLOB_BRACE);
	natcasesort($recherche);
	return $recherche;
}
// filtrage par type mime
public static function autorise($fichier) {
	$allowed_types = ['mp4','x-m4v','webm'];
	$video_type = substr(strrchr(mime_content_type($fichier), '/'),1);
	return in_array($video_type, $allowed_types);
}
// class
}
